@@ -204,7 +204,10 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	cairo_t          *cr;
-	
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (DETAIL ("notebook"))
@@ -247,6 +250,9 @@ clearlooks_style_draw_extension (DRAW_ARGS, GtkPositionType gap_side)
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	cairo_t          *cr;
 
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	if (DETAIL ("tab"))
@@ -826,6 +832,9 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	WidgetParameters params;
 	CheckboxParameters checkbox;
 	
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cairo_t *cr;
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
@@ -846,9 +855,11 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
 	WidgetParameters params;
 	CheckboxParameters checkbox;
-		
-
 	cairo_t *cr;
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
@@ -882,8 +893,9 @@ clearlooks_style_draw_vline                      (GtkStyle               *style,
 	SeparatorParameters separator = { FALSE };
 	cairo_t *cr;
 
-	colors = &clearlooks_style->colors;
+	CHECK_ARGS
 
+	colors = &clearlooks_style->colors;
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
@@ -909,6 +921,8 @@ clearlooks_style_draw_hline                      (GtkStyle               *style,
 	cairo_t *cr;
 	SeparatorParameters separator;
 
+	CHECK_ARGS
+
 	colors = &clearlooks_style->colors;
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
@@ -931,6 +945,9 @@ clearlooks_style_draw_shadow_gap (DRAW_ARGS,
 	const ClearlooksColors *colors;
 	cairo_t *cr;
 
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr     = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
 	
@@ -977,18 +994,17 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
-
 	cairo_t *cr;
-
 	WidgetParameters params;
 	ResizeGripParameters grip;
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	grip.edge = (ClearlooksWindowEdge)edge;
 
 	g_return_if_fail (window != NULL);
 
-	if (edge != GDK_WINDOW_EDGE_SOUTH_EAST)
-		return; /* sorry... need to work on this :P */
-	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);	
@@ -997,8 +1013,6 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 	                             x, y, width, height);
 
 	cairo_destroy (cr);
-
-	return;
 }
 
 static void
@@ -1008,8 +1022,12 @@ clearlooks_style_draw_tab (DRAW_ARGS)
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	WidgetParameters params;
 	ArrowParameters  arrow; 	 
+	cairo_t *cr;
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	CHECK_ARGS
+	SANITIZE_SIZE
+	
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
 	arrow.type      = CL_ARROW_COMBO;
@@ -1041,6 +1059,7 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
 	ArrowParameters  arrow;
 	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
 
+	CHECK_ARGS
 	SANITIZE_SIZE
 
 	if (arrow_type == GTK_ARROW_NONE) {
